@@ -23,6 +23,7 @@ import java.util.Optional;
 import java.util.SortedMap;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
+import java.util.stream.Stream;
 
 import org.drools.scenariosimulation.api.model.AbstractScesimModel;
 import org.drools.scenariosimulation.api.model.ExpressionElement;
@@ -43,6 +44,7 @@ import org.drools.workbench.screens.scenariosimulation.model.typedescriptor.Fact
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 
 import static org.drools.scenariosimulation.api.model.FactMapping.getPropertyPlaceHolder;
+import static org.drools.scenariosimulation.api.utils.ConstantsHolder.VALUE;
 import static org.drools.workbench.screens.scenariosimulation.client.utils.ScenarioSimulationUtils.getColumnSubGroup;
 import static org.drools.workbench.screens.scenariosimulation.client.utils.ScenarioSimulationUtils.getPropertyNameElementsWithoutAlias;
 
@@ -51,16 +53,13 @@ import static org.drools.workbench.screens.scenariosimulation.client.utils.Scena
  */
 public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGridCommand {
 
-    protected FactMappingValueType factMappingValueType = FactMappingValueType.NOT_EXPRESSION;
+    protected FactMappingValueType factMappingValueType;
 
     protected AbstractSelectedColumnCommand(GridWidget gridWidget, FactMappingValueType factMappingValueType) {
         super(gridWidget);
         this.factMappingValueType = factMappingValueType;
     }
 
-    protected AbstractSelectedColumnCommand() {
-    }
-
     protected abstract void executeIfSelectedColumn(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn);
 
     @Override
@@ -142,7 +141,7 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGrid
      */
     protected String getFullPackage(ScenarioSimulationContext context) {
         String fullPackage = context.getStatus().getFullPackage();
-        if (!fullPackage.endsWith(".")) {
+        if (!fullPackage.isEmpty() && !fullPackage.endsWith(".")) {
             fullPackage += ".";
         }
         return fullPackage;
@@ -157,7 +156,7 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGrid
      * @return
      */
     protected FactIdentifier setEditableHeadersAndGetFactIdentifier(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn, String aliasName, String canonicalClassName) {
-        final ScenarioSimulationModel.Type simulationModelType = context.getSettings().getType();
+        final ScenarioSimulationModel.Type simulationModelType = context.getScenarioSimulationModel().getSettings().getType();
         selectedColumn.setEditableHeaders(!(simulationModelType.equals(ScenarioSimulationModel.Type.DMN) || GridWidget.BACKGROUND.equals(gridWidget)));
         String nameToUseForCreation = simulationModelType.equals(ScenarioSimulationModel.Type.DMN) ? aliasName : selectedColumn.getInformationHeaderMetaData().getColumnId();
         return getFactIdentifierByColumnTitle(aliasName, context).orElseGet(() -> FactIdentifier.create(nameToUseForCreation, canonicalClassName));
@@ -182,9 +181,8 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGrid
      * @param propertyNameElements The <code>List</code> with the path instance_name.property.name (eg. Author.isAlive)
      * @param propertyClass it contains the full classname of the property (eg. com.Author)
      */
-    protected void setPropertyHeader(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn, List<String> propertyNameElements, String propertyClass) {
+    protected void setPropertyHeader(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn, String canonicalClassName, List<String> propertyNameElements, String propertyClass) {
         String instanceAliasName = propertyNameElements.get(0);
-        String canonicalClassName = getFullPackage(context) + instanceAliasName;
         final FactIdentifier factIdentifier = setEditableHeadersAndGetFactIdentifier(context, selectedColumn, instanceAliasName, canonicalClassName);
         String propertyTitle = getPropertyHeaderTitle(context, propertyNameElements, factIdentifier);
         this.setPropertyHeader(context, selectedColumn, factIdentifier, propertyNameElements, propertyClass, propertyTitle);
@@ -198,9 +196,8 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGrid
      * @param propertyClass it contains the full classname of the property (eg. com.Author)
      * @param propertyTitle The title to assign to this property.
      */
-    protected void setPropertyHeader(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn, List<String> propertyNameElements, String propertyClass, String propertyTitle) {
+    protected void setPropertyHeader(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn, String canonicalClassName, List<String> propertyNameElements, String propertyClass, String propertyTitle) {
         String instanceAliasName = propertyNameElements.get(0);
-        String canonicalClassName = getFullPackage(context) + instanceAliasName;
         final FactIdentifier factIdentifier = setEditableHeadersAndGetFactIdentifier(context, selectedColumn, instanceAliasName, canonicalClassName);
         this.setPropertyHeader(context, selectedColumn, factIdentifier, propertyNameElements, propertyClass, propertyTitle);
     }
@@ -245,13 +242,15 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGrid
         context.getAbstractScesimGridModelByGridWidget(gridWidget).updateColumnProperty(columnIndex,
                                                                                         selectedColumn,
                                                                                         propertyNameElements,
-                                                                                        propertyClass, context.getStatus().isKeepData(),
-                                                                                        factMappingValueType);
+                                                                                        propertyClass,
+                                                                                        context.getStatus().isKeepData(),
+                                                                                        factMappingValueType,
+                                                                                        context.getScenarioSimulationModel().getSettings().getType());
         if (ScenarioSimulationSharedUtils.isCollection(propertyClass) && factMappingValueType.equals(FactMappingValueType.NOT_EXPRESSION)) {
             manageCollectionProperty(context, selectedColumn, className, columnIndex, propertyNameElements);
         } else {
             selectedColumn.setFactory(context.getAbstractScesimGridModelByGridWidget(gridWidget).getDOMElementFactory(propertyClass,
-                                                                                                                      context.getSettings().getType(),
+                                                                                                                      context.getScenarioSimulationModel().getSettings().getType(),
                                                                                                                       factMappingValueType));
         }
         if (context.getScenarioSimulationEditorPresenter() != null) {
@@ -293,7 +292,7 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGrid
         final FactMapping factMapping = selectedScenarioGridModel.get().getScesimModelDescriptor().getFactMappingByIndex(columnIndex);
         selectedColumn.setFactory(context.getCollectionEditorSingletonDOMElementFactory(gridWidget));
         if (factModelTree.isSimple()) {
-            factMapping.setGenericTypes(factModelTree.getGenericTypeInfo(ConstantHolder.VALUE));
+            factMapping.setGenericTypes(factModelTree.getGenericTypeInfo(VALUE));
         } else {
             final FactModelTree nestedFactModelTree = navigateComplexObject(factModelTree,
                                                                             fullPropertyPathElements,
@@ -313,7 +312,7 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGrid
         if (pathElements.size() > 2) {
             for (String step : pathElements.subList(1, pathElements.size() - 1)) {
                 if (nestedFactModelTree.getExpandableProperties().containsKey(step)) {
-                    nestedFactModelTree = dataObjectFieldsMap.get(factModelTree.getExpandableProperties().get(step));
+                    nestedFactModelTree = dataObjectFieldsMap.get(nestedFactModelTree.getExpandableProperties().get(step));
                 }
             }
         }
@@ -323,18 +322,20 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGrid
     protected String getPropertyHeaderTitle(ScenarioSimulationContext context, List<String> propertyNameElements, FactIdentifier factIdentifier) {
         /* If propertyNameElements contains only one step, it's managing an Expression or a SimpleClass type */
         if (propertyNameElements.size() == 1) {
-            return FactMappingValueType.EXPRESSION.equals(factMappingValueType) ? ConstantHolder.EXPRESSION_INSTANCE_PLACEHOLDER : ConstantHolder.VALUE;
+            return FactMappingValueType.EXPRESSION.equals(factMappingValueType) ? ConstantHolder.EXPRESSION_INSTANCE_PLACEHOLDER : VALUE;
         }
         String propertyPathPart = String.join(".", propertyNameElements.subList(1, propertyNameElements.size()));
-        List<String> propertyNameElementsClone = getPropertyNameElementsWithoutAlias(propertyNameElements, factIdentifier);
+        List<String> propertyNameElementsClone = getPropertyNameElementsWithoutAlias(propertyNameElements,
+                                                                                     factIdentifier,
+                                                                                     context.getScenarioSimulationModel().getSettings().getType());
         // This is because the propertyName starts with the alias of the fact; i.e. it may be Book.name but also Bookkk.name,
         // while the first element of ExpressionElements is always the class name
         return getMatchingExpressionAlias(context, propertyNameElementsClone, factIdentifier).orElse(propertyPathPart);
     }
 
     protected Optional<String> getMatchingExpressionAlias(ScenarioSimulationContext context, List<String> propertyNameElements, FactIdentifier factIdentifier) {
-        final List<FactMapping> factMappingsByFactName = context.getAbstractScesimModelByGridWidget(gridWidget).getScesimModelDescriptor().getFactMappingsByFactName(factIdentifier.getName());
-        return factMappingsByFactName.stream()
+        final Stream<FactMapping> factMappingsByFactName = context.getAbstractScesimModelByGridWidget(gridWidget).getScesimModelDescriptor().getFactMappingsByFactName(factIdentifier.getName());
+        return factMappingsByFactName
                 .filter(factMapping -> {
                     List<String> expressionElements = factMapping.getExpressionElements().stream().map(ExpressionElement::getStep).collect(Collectors.toList());
                     return Objects.equals(expressionElements, propertyNameElements);
