@@ -36,11 +36,14 @@ import org.drools.scenariosimulation.api.model.ScesimModelDescriptor;
 import org.drools.workbench.screens.scenariosimulation.client.commands.ScenarioSimulationContext;
 import org.drools.workbench.screens.scenariosimulation.client.enums.GridWidget;
 import org.drools.workbench.screens.scenariosimulation.client.models.AbstractScesimGridModel;
+import org.drools.workbench.screens.scenariosimulation.client.rightpanel.TestToolsPresenterData;
 import org.drools.workbench.screens.scenariosimulation.client.rightpanel.TestToolsView;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridColumn;
 import org.drools.workbench.screens.scenariosimulation.model.typedescriptor.FactModelTree;
 import org.drools.workbench.screens.scenariosimulation.model.typedescriptor.FactModelTuple;
 
+import static org.drools.scenariosimulation.api.utils.ConstantsHolder.VALUE;
+
 /**
  * Abstract class to provide common methods to be used by actual implementations.
  */
@@ -55,12 +58,11 @@ public abstract class AbstractDataManagementStrategy implements DataManagementSt
     }
 
     public static FactModelTree getSimpleClassFactModelTree(String simpleClass, String canonicalName) {
-        String key = simpleClass;
-        Map<String, String> simpleProperties = new HashMap<>();
-        String fullName = canonicalName;
-        simpleProperties.put("value", fullName);
-        String packageName = fullName.substring(0, fullName.lastIndexOf('.'));
-        FactModelTree toReturn = new FactModelTree(key, packageName, simpleProperties, new HashMap<>());
+        Map<String, FactModelTree.PropertyTypeName> simpleProperties = new HashMap<>();
+        simpleProperties.put(VALUE, new FactModelTree.PropertyTypeName(canonicalName));
+        String packageName = canonicalName.substring(0, canonicalName.lastIndexOf('.'));
+        String factClassName = canonicalName.substring(canonicalName.lastIndexOf('.') + 1);
+        FactModelTree toReturn = FactModelTree.ofDMO(simpleClass, packageName, simpleProperties, new HashMap<>(), factClassName);
         toReturn.setSimple(true);
         return toReturn;
     }
@@ -114,7 +116,7 @@ public abstract class AbstractDataManagementStrategy implements DataManagementSt
                                                     .map(ExpressionElement::getStep)
                                                     .collect(Collectors.toList());
                                             if (propertyNameElements.isEmpty()) {
-                                                propertyNameElements.add("value");
+                                                propertyNameElements.add(VALUE);
                                             }
                                             return Collections.unmodifiableList(propertyNameElements);
                                         })
@@ -139,35 +141,34 @@ public abstract class AbstractDataManagementStrategy implements DataManagementSt
         final SortedMap<String, FactModelTree> complexDataObjects = new TreeMap<>(partitionBy.get(false).stream().collect(Collectors.toMap(Map.Entry::getKey, Map.Entry::getValue)));
         final SortedMap<String, FactModelTree> simpleDataObjects = new TreeMap<>(partitionBy.get(true).stream().collect(Collectors.toMap(Map.Entry::getKey, Map.Entry::getValue)));
 
-
-        // Update right panel
-        testToolsPresenter.setDataObjectFieldsMap(complexDataObjects);
-        testToolsPresenter.setSimpleJavaTypeFieldsMap(simpleDataObjects);
-        testToolsPresenter.setHiddenFieldsMap(factModelTuple.getHiddenFacts());
-        testToolsPresenter.hideProperties(propertiesToHide);
         // Update context
         SortedMap<String, FactModelTree> dataObjectFieldsMap = new TreeMap<>();
         dataObjectFieldsMap.putAll(visibleFacts);
         dataObjectFieldsMap.putAll(factModelTuple.getHiddenFacts());
         context.setDataObjectFieldsMap(dataObjectFieldsMap);
-        testToolsPresenter.hideInstances();
         // Update model
+        // Avoid Collections.emptySortedMap() due to "The method emptySortedMap() is undefined for the type Collections" error
+        SortedMap<String, FactModelTree> instanceFieldsMap = new TreeMap<>();
+        SortedMap<String, FactModelTree> simpleJavaTypeInstanceFieldsMap = new TreeMap<>();
         if (GridWidget.SIMULATION.equals(gridWidget)) {
-            final SortedMap<String, FactModelTree> instanceFieldsMap = getInstanceMap(complexDataObjects);
-            final SortedMap<String, FactModelTree> simpleJavaTypeInstanceFieldsMap = getInstanceMap(simpleDataObjects);
-            testToolsPresenter.setInstanceFieldsMap(instanceFieldsMap);
-            testToolsPresenter.setSimpleJavaInstanceFieldsMap(simpleJavaTypeInstanceFieldsMap);
+            instanceFieldsMap = getInstanceMap(complexDataObjects);
+            simpleJavaTypeInstanceFieldsMap = getInstanceMap(simpleDataObjects);
             Set<String> dataObjectsInstancesName = new HashSet<>(visibleFacts.keySet());
             dataObjectsInstancesName.addAll(instanceFieldsMap.keySet());
             context.setDataObjectsInstancesName(dataObjectsInstancesName);
             Set<String> simpleJavaTypeInstancesName = new HashSet<>(simpleDataObjects.keySet());
             simpleJavaTypeInstancesName.addAll(simpleJavaTypeInstanceFieldsMap.keySet());
             context.getAbstractScesimGridModelByGridWidget(gridWidget).setSimpleJavaTypeInstancesName(simpleJavaTypeInstancesName);
-        } else {
-            // Avoid Collections.emptySortedMap() due to "The method emptySortedMap() is undefined for the type Collections" error
-            testToolsPresenter.setInstanceFieldsMap(new TreeMap<>());
-            testToolsPresenter.setSimpleJavaInstanceFieldsMap(new TreeMap<>());
         }
+        // Update right panel
+        TestToolsPresenterData testToolsPresenterData = new TestToolsPresenterData(complexDataObjects,
+                                                                                   simpleDataObjects,
+                                                                                   instanceFieldsMap,
+                                                                                   simpleJavaTypeInstanceFieldsMap,
+                                                                                   factModelTuple.getHiddenFacts(),
+                                                                                   propertiesToHide,
+                                                                                   gridWidget);
+        testToolsPresenter.populateTestTools(testToolsPresenterData);
     }
 
     /**
@@ -180,11 +181,14 @@ public abstract class AbstractDataManagementStrategy implements DataManagementSt
         // map instance name to base class
         if (model != null) {
             final ScesimModelDescriptor simulationDescriptor = model.getSimulation().getScesimModelDescriptor();
+            final ScenarioSimulationModel.Type type = model.getSettings().getType();
             simulationDescriptor.getUnmodifiableFactMappings()
                     .stream()
                     .filter(factMapping -> !Objects.equals(FactMappingType.OTHER, factMapping.getExpressionIdentifier().getType()))
                     .forEach(factMapping -> {
-                        String dataObjectName = factMapping.getFactIdentifier().getClassNameWithoutPackage();
+                        String dataObjectName = ScenarioSimulationModel.Type.DMN.equals(type) ?
+                                factMapping.getFactIdentifier().getClassName() :
+                                factMapping.getFactIdentifier().getClassNameWithoutPackage().replace("$", ".");
                         final String instanceName = factMapping.getFactAlias();
                         if (!instanceName.equals(dataObjectName)) {
                             final FactModelTree factModelTree = sourceMap.get(dataObjectName);
