@@ -16,6 +16,7 @@
 
 package org.drools.workbench.screens.scenariosimulation.client.rightpanel;
 
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
@@ -27,8 +28,6 @@ import java.util.TreeMap;
 import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;
 
-import com.google.gwt.dom.client.DivElement;
-import com.google.gwt.dom.client.Style;
 import com.google.gwt.event.shared.EventBus;
 import org.drools.scenariosimulation.api.model.FactMappingValueType;
 import org.drools.workbench.screens.scenariosimulation.client.enums.GridWidget;
@@ -84,71 +83,39 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
         onPerfectMatchSearchedEvent(listGroupItemPresenter.getFilterTerm(), true);
     }
 
-    @Override
-    public void onClearNameField() {
-        view.clearNameField();
-    }
-
     @Override
     public void onClearStatus() {
         onClearSearch();
-        onClearNameField();
     }
 
     @Override
     public void clearDataObjectList() {
-        view.getDataObjectListContainer().removeAllChildren();
+        view.clearDataObjectList();
     }
 
     @Override
     public void clearSimpleJavaTypeList() {
-        view.getSimpleJavaTypeListContainer().removeAllChildren();
+        view.clearSimpleJavaTypeList();
     }
 
     @Override
     public void clearInstanceList() {
-        view.getInstanceListContainer().removeAllChildren();
+        view.clearInstanceList();
     }
 
     @Override
     public void clearSimpleJavaInstanceFieldList() {
-        view.getSimpleJavaInstanceListContainer().removeAllChildren();
-    }
-
-    @Override
-    public void updateDataObjectListSeparator() {
-        if (view.getDataObjectListContainer().getChildCount() == 0) {
-            view.getDataObjectListContainerSeparator().getStyle().setDisplay(Style.Display.NONE);
-        } else {
-            view.getDataObjectListContainerSeparator().getStyle().setDisplay(Style.Display.BLOCK);
-        }
-    }
-
-    @Override
-    public void updateSimpleJavaTypeListSeparator() {
-        if (view.getSimpleJavaTypeListContainer().getChildCount() == 0) {
-            view.getSimpleJavaTypeListContainerSeparator().getStyle().setDisplay(Style.Display.NONE);
-        } else {
-            view.getSimpleJavaTypeListContainerSeparator().getStyle().setDisplay(Style.Display.BLOCK);
-        }
+        view.clearSimpleJavaInstanceFieldList();
     }
 
     @Override
     public void updateInstanceListSeparator() {
-        if (view.getInstanceListContainer().getChildCount() < 1 || GridWidget.BACKGROUND.equals(gridWidget)) {
-            view.getInstanceListContainerSeparator().getStyle().setDisplay(Style.Display.NONE);
-        } else {
-            view.getInstanceListContainerSeparator().getStyle().setDisplay(Style.Display.BLOCK);
-        }
+        view.updateInstanceListSeparator(GridWidget.SIMULATION.equals(gridWidget));
     }
 
     @Override
-    public void updateSimpleJavaInstanceFieldListSeparator() {
-        if (view.getSimpleJavaInstanceListContainer().getChildCount() < 1 || GridWidget.BACKGROUND.equals(gridWidget)) {
-            view.getSimpleJavaInstanceListContainerSeparator().getStyle().setDisplay(Style.Display.NONE);
-        } else {
-            view.getSimpleJavaInstanceListContainerSeparator().getStyle().setDisplay(Style.Display.BLOCK);
-        }
+    public void showInstanceListContainerSeparator(boolean show) {
+        view.showInstanceListContainerSeparator(show);
     }
 
     @Override
@@ -177,44 +144,47 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
     }
 
     @Override
-    public void setDataObjectFieldsMap(SortedMap<String, FactModelTree> dataObjectFieldsMap) {
+    public void populateTestTools(TestToolsPresenterData data) {
+        setDataObjectFieldsMap(data.getDataObjectFieldsMap());
+        setSimpleJavaTypeFieldsMap(data.getSimpleJavaTypeFieldsMap());
+        setInstanceFieldsMap(data.getInstanceFieldsMap());
+        setSimpleJavaInstanceFieldsMap(data.getSimpleJavaInstanceFieldsMap());
+        setHiddenFieldsMap(data.getHiddenFieldsMap());
+        hideProperties(data.getPropertiesToHide());
+        setGridWidget(data.getGridWidget());
+    }
+
+    protected void setDataObjectFieldsMap(SortedMap<String, FactModelTree> dataObjectFieldsMap) {
         clearDataObjectList();
         this.dataObjectFieldsMap = dataObjectFieldsMap;
         this.dataObjectFieldsMap.forEach(this::addDataObjectListGroupItemView);
-        updateDataObjectListSeparator();
     }
 
-    @Override
-    public void setSimpleJavaTypeFieldsMap(SortedMap<String, FactModelTree> simpleJavaTypeFieldsMap) {
+    protected void setSimpleJavaTypeFieldsMap(SortedMap<String, FactModelTree> simpleJavaTypeFieldsMap) {
         clearSimpleJavaTypeList();
         this.simpleJavaTypeFieldsMap = simpleJavaTypeFieldsMap;
         this.simpleJavaTypeFieldsMap.forEach(this::addSimpleJavaTypeListGroupItemView);
-        updateSimpleJavaTypeListSeparator();
     }
 
-    @Override
-    public void setInstanceFieldsMap(SortedMap<String, FactModelTree> instanceFieldsMap) {
+    protected void setInstanceFieldsMap(SortedMap<String, FactModelTree> instanceFieldsMap) {
         clearInstanceList();
         this.instanceFieldsMap = instanceFieldsMap;
         this.instanceFieldsMap.forEach(this::addInstanceListGroupItemView);
         updateInstanceListSeparator();
     }
 
-    @Override
-    public void setSimpleJavaInstanceFieldsMap(SortedMap<String, FactModelTree> simpleJavaInstanceFieldsMap) {
+    protected void setSimpleJavaInstanceFieldsMap(SortedMap<String, FactModelTree> simpleJavaInstanceFieldsMap) {
         clearSimpleJavaInstanceFieldList();
         this.simpleJavaInstanceFieldsMap = simpleJavaInstanceFieldsMap;
         this.simpleJavaInstanceFieldsMap.forEach(this::addSimpleJavaInstanceListGroupItemView);
-        updateSimpleJavaInstanceFieldListSeparator();
+        updateInstanceListSeparator();
     }
 
-    @Override
-    public void setHiddenFieldsMap(SortedMap<String, FactModelTree> hiddenFieldsMap) {
+    protected void setHiddenFieldsMap(SortedMap<String, FactModelTree> hiddenFieldsMap) {
         this.hiddenFieldsMap = hiddenFieldsMap;
     }
 
-    @Override
-    public void hideProperties(Map<String, List<List<String>>> propertiesToHide) {
+    protected void hideProperties(Map<String, List<List<String>>> propertiesToHide) {
         listGroupItemPresenter.showAll();
         propertiesToHide.entrySet().stream().forEach(
                 stringListEntry -> stringListEntry.getValue()
@@ -233,18 +203,10 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
         this.eventBus = eventBus;
     }
 
-    @Override
-    public void setGridWidget(GridWidget gridWidget) {
+    protected void setGridWidget(GridWidget gridWidget) {
         this.gridWidget = gridWidget;
-        switch (gridWidget) {
-            case BACKGROUND:
-                hideInstances();
-                break;
-            case SIMULATION:
-                showInstances();
-                break;
-            default:
-                throw new IllegalArgumentException("Illegal GridWidget " + gridWidget);
+        if (GridWidget.BACKGROUND.equals(gridWidget)) {
+            hideInstances();
         }
     }
 
@@ -261,19 +223,17 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
                 .stream()
                 .filter(entry -> entry.getKey().toLowerCase().contains(search.toLowerCase()))
                 .forEach(filteredEntry -> addSimpleJavaTypeListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
-//        if (GridWidget.SIMULATION.equals(gridWidget)) {
-            instanceFieldsMap
-                    .entrySet()
-                    .stream()
-                    .filter(entry -> entry.getKey().toLowerCase().contains(search.toLowerCase()))
-                    .forEach(filteredEntry -> addInstanceListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
-            simpleJavaInstanceFieldsMap
-                    .entrySet()
-                    .stream()
-                    .filter(entry -> entry.getKey().toLowerCase().contains(search.toLowerCase()))
-                    .forEach(filteredEntry -> addSimpleJavaInstanceListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
-//        }
-        updateSeparators();
+        instanceFieldsMap
+                .entrySet()
+                .stream()
+                .filter(entry -> entry.getKey().toLowerCase().contains(search.toLowerCase()))
+                .forEach(filteredEntry -> addInstanceListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
+        simpleJavaInstanceFieldsMap
+                .entrySet()
+                .stream()
+                .filter(entry -> entry.getKey().toLowerCase().contains(search.toLowerCase()))
+                .forEach(filteredEntry -> addSimpleJavaInstanceListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
+        updateInstanceListSeparator();
     }
 
     @Override
@@ -289,43 +249,37 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
                 .stream()
                 .filter(entry -> filterTerm(entry.getKey(), search, notEqualsSearch))
                 .forEach(filteredEntry -> addSimpleJavaTypeListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
-//        if (GridWidget.SIMULATION.equals(gridWidget)) {
-            instanceFieldsMap
-                    .entrySet()
-                    .stream()
-                    .filter(entry -> filterTerm(entry.getKey(), search, notEqualsSearch))
-                    .forEach(filteredEntry -> addInstanceListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
-            simpleJavaInstanceFieldsMap
-                    .entrySet()
-                    .stream()
-                    .filter(entry -> filterTerm(entry.getKey(), search, notEqualsSearch))
-                    .forEach(filteredEntry -> addSimpleJavaInstanceListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
-//        }
-        updateSeparators();
+        instanceFieldsMap
+                .entrySet()
+                .stream()
+                .filter(entry -> filterTerm(entry.getKey(), search, notEqualsSearch))
+                .forEach(filteredEntry -> addInstanceListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
+        simpleJavaInstanceFieldsMap
+                .entrySet()
+                .stream()
+                .filter(entry -> filterTerm(entry.getKey(), search, notEqualsSearch))
+                .forEach(filteredEntry -> addSimpleJavaInstanceListGroupItemView(filteredEntry.getKey(), filteredEntry.getValue()));
+        updateInstanceListSeparator();
     }
 
     @Override
     public void addDataObjectListGroupItemView(String factName, FactModelTree factModelTree) {
-        DivElement toAdd = listGroupItemPresenter.getDivElement(factName, factModelTree);
-        view.getDataObjectListContainer().appendChild(toAdd);
+        view.addDataObjectListGroupItem(listGroupItemPresenter.getDivElement(factName, factModelTree));
     }
 
     @Override
     public void addSimpleJavaTypeListGroupItemView(String factName, FactModelTree factModelTree) {
-        DivElement toAdd = listGroupItemPresenter.getDivElement(factName, factModelTree);
-        view.getSimpleJavaTypeListContainer().appendChild(toAdd);
+        view.addSimpleJavaTypeListGroupItem(listGroupItemPresenter.getDivElement(factName, factModelTree));
     }
 
     @Override
     public void addInstanceListGroupItemView(String instanceName, FactModelTree factModelTree) {
-        DivElement toAdd = listGroupItemPresenter.getDivElement(instanceName, factModelTree);
-        view.getInstanceListContainer().appendChild(toAdd);
+        view.addInstanceListGroupItem(listGroupItemPresenter.getDivElement(instanceName, factModelTree));
     }
 
     @Override
     public void addSimpleJavaInstanceListGroupItemView(String instanceName, FactModelTree factModelTree) {
-        DivElement toAdd = listGroupItemPresenter.getDivElement(instanceName, factModelTree);
-        view.getSimpleJavaInstanceListContainer().appendChild(toAdd);
+        view.addSimpleJavaInstanceListGroupItem(listGroupItemPresenter.getDivElement(instanceName, factModelTree));
     }
 
     @Override
@@ -382,46 +336,72 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
     public void setSelectedElement(FieldItemView selected) {
         selectedFieldItemView = selected;
         selectedListGroupItemView = null;
-        String factName = selectedFieldItemView.getFullPath().split("\\.")[0];
+        String factName = selectedFieldItemView.getFullPath().get(0);
         boolean isFactNameAssigned = listGroupItemPresenter.isInstanceAssigned(factName);
-        if (filterTerm(factName, listGroupItemPresenter.getFilterTerm(), isFactNameAssigned)) {
+        /* If the check is not shown, the item was not selected by an user but automatically. If it's shown,
+           then it checks if the related instance is already assigned or not. */
+        if (!selectedFieldItemView.isCheckShown() ||
+                filterTerm(factName, listGroupItemPresenter.getFilterTerm(), isFactNameAssigned)) {
             view.disableAddButton();
         } else {
             view.enableAddButton();
         }
     }
 
+    @Override
+    public void clearSelection() {
+        if (selectedFieldItemView != null) {
+            selectedFieldItemView.showCheck(false);
+        } else if (selectedListGroupItemView != null) {
+            selectedListGroupItemView.showCheck(false);
+        }
+        view.disableAddButton();
+    }
+
     @Override
     public void onModifyColumn() {
         if (editingColumnEnabled) {
             if (selectedListGroupItemView != null) {
                 String className = selectedListGroupItemView.getActualClassName();
-                getFullPackage(className).ifPresent(fullPackage -> eventBus.fireEvent(
-                            new SetPropertyHeaderEvent(gridWidget,
-                                                       fullPackage,
-                                                       Arrays.asList(className),
-                                                       fullPackage + "." + className,
-                                                       FactMappingValueType.EXPRESSION)));
+                getFactModelTreeFromMaps(className).ifPresent(factModelTree -> eventBus.fireEvent(
+                    new SetPropertyHeaderEvent(gridWidget,
+                                               factModelTree.getFullPackage(),
+                                               factModelTree.getTypeName(),
+                                               Collections.unmodifiableList(Arrays.asList(className)),
+                                               factModelTree.getFullTypeName(),
+                                               FactMappingValueType.EXPRESSION)));
             } else if (selectedFieldItemView != null) {
-                String baseClass = selectedFieldItemView.getFullPath().split("\\.")[0];
-                String value = isSimple(baseClass) ?
-                        selectedFieldItemView.getFullPath() :
-                        selectedFieldItemView.getFullPath() + "." + selectedFieldItemView.getFieldName();
-                List<String> propertyNameElements = Collections.unmodifiableList(Arrays.asList(value.split("\\.")));
-                getFullPackage(baseClass).ifPresent(fullPackage -> eventBus.fireEvent(new SetPropertyHeaderEvent(gridWidget, fullPackage,
-                                                                                                                 propertyNameElements,
-                                                                                                                 selectedFieldItemView.getClassName(),
-                                                                                                                 FactMappingValueType.NOT_EXPRESSION)));
+                String baseClass = selectedFieldItemView.getFullPath().get(0);
+                List<String> propertyNameElements = new ArrayList<>(selectedFieldItemView.getFullPath());
+                if (!isSimple(baseClass)) {
+                    propertyNameElements.add(selectedFieldItemView.getFieldName());
+                }
+                getFactModelTreeFromMaps(baseClass).ifPresent(factModelTree -> eventBus.fireEvent(
+                    new SetPropertyHeaderEvent(gridWidget,
+                                               factModelTree.getFullPackage(),
+                                               factModelTree.getTypeName(),
+                                               Collections.unmodifiableList(propertyNameElements),
+                                               selectedFieldItemView.getClassName(),
+                                               FactMappingValueType.NOT_EXPRESSION)));
             }
         }
     }
 
     @Override
     public void reset() {
+        clearFieldsMaps();
         listGroupItemPresenter.reset();
         view.reset();
     }
 
+    protected void clearFieldsMaps() {
+        dataObjectFieldsMap = new TreeMap<>();
+        simpleJavaTypeFieldsMap = new TreeMap<>();
+        instanceFieldsMap = new TreeMap<>();
+        simpleJavaInstanceFieldsMap = new TreeMap<>();
+        hiddenFieldsMap = new TreeMap<>();
+    }
+
     /**
      * Method to hide all the <b>instance-related</b> html
      */
@@ -429,16 +409,7 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
     public void hideInstances() {
         clearInstanceList();
         clearSimpleJavaInstanceFieldList();
-        view.getInstanceListContainerSeparator().getStyle().setDisplay(Style.Display.NONE);
-        view.getSimpleJavaInstanceListContainerSeparator().getStyle().setDisplay(Style.Display.NONE);
-    }
-
-    /**
-     * Method to show all the <b>instance-related</b> html
-     */
-    protected void showInstances() {
-        view.getInstanceListContainerSeparator().getStyle().setDisplay(Style.Display.BLOCK);
-        view.getSimpleJavaInstanceListContainerSeparator().getStyle().setDisplay(Style.Display.BLOCK);
+        showInstanceListContainerSeparator(false);
     }
 
     /**
@@ -469,9 +440,9 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
     }
 
     protected boolean isSimple(String key) {
-        return Optional.ofNullable(getFactModelTreeFromSimpleJavaTypeMap(key))
-                .orElseGet(() -> getFactModelTreeFromSimpleJavaInstanceMap(key))
-                .isPresent();
+        return Optional.ofNullable(getFactModelTreeFromSimpleJavaTypeMap(key)
+                                           .orElseGet(() -> getFactModelTreeFromSimpleJavaInstanceMap(key)
+                                                   .orElse(null))).isPresent();
     }
 
     protected void clearLists() {
@@ -481,13 +452,6 @@ public class TestToolsPresenter extends AbstractSubDockPresenter<TestToolsView>
         clearSimpleJavaInstanceFieldList();
     }
 
-    protected void updateSeparators() {
-        updateDataObjectListSeparator();
-        updateSimpleJavaTypeListSeparator();
-        updateInstanceListSeparator();
-        updateSimpleJavaInstanceFieldListSeparator();
-    }
-
     /**
      * It determines if a key (factTitle) is present or not in the search variable.
      * @param key It's the title of the fact to search
