@@ -15,6 +15,8 @@
  */
 package org.drools.workbench.screens.scenariosimulation.client.widgets;
 
+import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.Optional;
@@ -74,6 +76,7 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyBoolean;
 import static org.mockito.Matchers.anyInt;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
@@ -391,7 +394,7 @@ public class ScenarioGridTest {
 
         verify(scenarioGridSpy).signalTestTools();
         verify(scenarioGridSpy).setSelectedColumn(eq(uiColumnIndex));
-        verify(eventBusMock).fireEvent(any(EnableTestToolsEvent.class));
+        verify(eventBusMock).fireEvent(any());
 
         // context menus could be shown
         verify(scenarioContextMenuRegistryMock, times(1)).hideMenus();
@@ -505,4 +508,67 @@ public class ScenarioGridTest {
         scenarioGridSpy.signalTestToolsHeaderCellSelected(columnMock, selectedHeaderCell, uiColumnIndex);
         verify(eventBusMock, times(1)).fireEvent(isA(ReloadTestToolsEvent.class));
     }
+
+    @Test
+    public void ensureCellIsSelected_EmptyGrid() {
+        when(scenarioGridModelMock.getColumnCount()).thenReturn(0);
+        scenarioGridSpy.ensureCellIsSelected();
+        verify(scenarioGridSpy, never()).selectCell(anyInt(), anyInt(), anyBoolean(), anyBoolean());
+        verify(scenarioGridSpy, never()).signalTestTools();
+    }
+
+    @Test
+    public void reselectCurrentHeaderCell() {
+        final ScenarioGridColumn columnMock = mock(ScenarioGridColumn.class);
+        when(columnMock.getIndex()).thenReturn(0);
+        when(scenarioGridModelMock.getColumns()).thenReturn(Collections.singletonList(columnMock));
+        List<GridData.SelectedCell> selectedHeaderCells = new ArrayList<>();
+        selectedHeaderCells.add(new GridData.SelectedCell(0, 0));
+        when(scenarioGridModelMock.getSelectedHeaderCells()).thenReturn(selectedHeaderCells);
+        scenarioGridSpy.selectCurrentHeaderCellGroup();
+        verify(scenarioGridSpy, times(1)).setSelectedColumnAndHeader(eq(0), eq(0));
+    }
+
+    @Test
+    public void reselectCurrentHeaderCellMultipleColumns() {
+        final ScenarioGridColumn columnMock = mock(ScenarioGridColumn.class);
+        when(columnMock.getIndex()).thenReturn(0);
+        final ScenarioGridColumn columnMock2 = mock(ScenarioGridColumn.class);
+        when(columnMock2.getIndex()).thenReturn(1);
+        final ScenarioGridColumn columnMock3 = mock(ScenarioGridColumn.class);
+        when(columnMock3.getIndex()).thenReturn(2);
+        when(scenarioGridModelMock.getColumns()).thenReturn(Arrays.asList(columnMock, columnMock2, columnMock3));
+        List<GridData.SelectedCell> selectedHeaderCells = new ArrayList<>();
+        selectedHeaderCells.add(new GridData.SelectedCell(0, 0));
+        selectedHeaderCells.add(new GridData.SelectedCell(0, 1));
+        selectedHeaderCells.add(new GridData.SelectedCell(0, 2));
+        when(scenarioGridModelMock.getSelectedHeaderCells()).thenReturn(selectedHeaderCells);
+        scenarioGridSpy.selectCurrentHeaderCellGroup();
+        verify(scenarioGridSpy, times(1)).setSelectedColumnAndHeader(eq(0), eq(0));
+    }
+
+    @Test
+    public void reselectCurrentHeaderCellMultipleMiddleColumns() {
+        final ScenarioGridColumn columnMock = mock(ScenarioGridColumn.class);
+        when(columnMock.getIndex()).thenReturn(0);
+        final ScenarioGridColumn columnMock2 = mock(ScenarioGridColumn.class);
+        when(columnMock2.getIndex()).thenReturn(1);
+        final ScenarioGridColumn columnMock3 = mock(ScenarioGridColumn.class);
+        when(columnMock3.getIndex()).thenReturn(2);
+        when(scenarioGridModelMock.getColumns()).thenReturn(Arrays.asList(columnMock, columnMock2, columnMock3));
+        List<GridData.SelectedCell> selectedHeaderCells = new ArrayList<>();
+        selectedHeaderCells.add(new GridData.SelectedCell(0, 1));
+        selectedHeaderCells.add(new GridData.SelectedCell(0, 2));
+        when(scenarioGridModelMock.getSelectedHeaderCells()).thenReturn(selectedHeaderCells);
+        scenarioGridSpy.selectCurrentHeaderCellGroup();
+        verify(scenarioGridSpy, times(1)).setSelectedColumnAndHeader(eq(0), eq(1));
+    }
+
+    @Test
+    public void reselectCurrentHeaderCell_NoHeaderCellsSelected() {
+        List<GridData.SelectedCell> selectedHeaderCells = new ArrayList<>();
+        when(scenarioGridModelMock.getSelectedHeaderCells()).thenReturn(selectedHeaderCells);
+        scenarioGridSpy.selectCurrentHeaderCellGroup();
+        verify(scenarioGridSpy, never()).setSelectedColumnAndHeader(anyInt(), anyInt());
+    }
 }
\ No newline at end of file
